@@ -5,6 +5,8 @@
  *
  * This file is part of Kamailio, a free SIP server.
  *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ *
  * Kamailio is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -444,20 +446,28 @@ int print_rr_body(
 		i = (nb_recs == NULL) ? 0 : *nb_recs;
 
 		while(i < n) {
-			memcpy(cp, route[i].s, route[i].len);
-			cp += route[i].len;
-			if(++i < n)
-				*(cp++) = ',';
+			if(route[i].s != NULL) {
+				memcpy(cp, route[i].s, route[i].len);
+				cp += route[i].len;
+				if(++i < n)
+					*(cp++) = ',';
+			} else {
+				i++;
+			}
 		}
 	} else {
 
 		i = (nb_recs == NULL) ? n - 1 : (n - *nb_recs - 1);
 
 		while(i >= 0) {
-			memcpy(cp, route[i].s, route[i].len);
-			cp += route[i].len;
-			if(i-- > 0)
-				*(cp++) = ',';
+			if(route[i].s != NULL) {
+				memcpy(cp, route[i].s, route[i].len);
+				cp += route[i].len;
+				if(i-- > 0)
+					*(cp++) = ',';
+			} else {
+				i--;
+			}
 		}
 	}
 	oroute->len = cp - start;
