@@ -343,9 +343,9 @@ int legs2strar(struct acc_extra *legs, struct sip_msg *rq, str *val_arr,
 {
 	static struct usr_avp *avp[MAX_ACC_LEG];
 	static struct search_state st[MAX_ACC_LEG];
-	unsigned short name_type;
-	int_str name;
-	int_str value;
+	avp_flags_t name_type;
+	avp_name_t name;
+	avp_value_t value;
 	int n;
 	int found;
 	int r;
