@@ -3,6 +3,8 @@
  *
  * This file is part of Kamailio, a free SIP server.
  *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ *
  * Kamailio is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -64,8 +66,8 @@ int _ksr_app_lua_log_mode = 0;
 
 /* clang-format off */
 static param_export_t params[] = {
-	{"load", PARAM_STRING | USE_FUNC_PARAM, (void *)app_lua_load_param},
-	{"reload", INT_PARAM | USE_FUNC_PARAM, (void *)app_lua_reload_param},
+	{"load", PARAM_STRING | PARAM_USE_FUNC, (void *)app_lua_load_param},
+	{"reload", PARAM_INT | PARAM_USE_FUNC, (void *)app_lua_reload_param},
 	{"log_mode", PARAM_INT, &_ksr_app_lua_log_mode},
 	{0, 0, 0}
 };
