@@ -5,6 +5,8 @@
  *
  * This file is part of Kamailio, a free SIP server.
  *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ *
  * Kamailio is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -35,21 +37,21 @@
 
 struct cpl_environment
 {
-	char *log_dir;			/* dir where the user log should be dumped */
-	int proxy_recurse;		/* numbers of proxy redirection accepted */
-	int proxy_route;		/* script route to be run before proxy */
-	int redirect_route;		/* script route to be run before redirect */
-	int ignore3xx;			/* deactivate 3xx responses handling */
-	int case_sensitive;		/* is user part case sensitive ? */
-	str realm_prefix;		/* domain prefix to be ignored */
-	int cmd_pipe[2];		/* communication pipe with aux. process */
-	str orig_tz;			/* a copy of the original TZ; kept as a null
+	char *log_dir;				/* dir where the user log should be dumped */
+	int proxy_recurse;			/* numbers of proxy redirection accepted */
+	int proxy_route;			/* script route to be run before proxy */
+	int redirect_route;			/* script route to be run before redirect */
+	int ignore3xx;				/* deactivate 3xx responses handling */
+	int case_sensitive;			/* is user part case sensitive ? */
+	str realm_prefix;			/* domain prefix to be ignored */
+	int cmd_pipe[2];			/* communication pipe with aux. process */
+	str orig_tz;				/* a copy of the original TZ; kept as a null
                              * terminated string in "TZ=value" format;
                              * used only by run_time_switch */
-	udomain_t *lu_domain;	/* domain used for lookup */
-	int lu_append_branches; /* how many branches lookup should add */
-	int timer_avp_type;		/* specs - type and name - of the timer AVP */
-	int_str timer_avp;
+	udomain_t *lu_domain;		/* domain used for lookup */
+	int lu_append_branches;		/* how many branches lookup should add */
+	avp_flags_t timer_avp_type; /* specs - type and name - of the timer AVP */
+	avp_name_t timer_avp;
 	int use_domain;
 };
 
