@@ -37,7 +37,6 @@
 int dlg_register_cseq_callbacks(void);
 
 int dlg_cseq_update(sip_msg_t *msg);
-int dlg_cseq_refresh(sip_msg_t *msg, dlg_cell_t *dlg,
-		unsigned int direction);
+int dlg_cseq_refresh(sip_msg_t *msg, dlg_cell_t *dlg, unsigned int direction);
 
 #endif
