@@ -54,46 +54,51 @@ extern int _evapi_max_clients;
 extern int _evapi_wait_idle;
 extern int _evapi_wait_increase;
 
-#define EVAPI_IPADDR_SIZE	64
-#define EVAPI_TAG_SIZE	64
-#define CLIENT_BUFFER_SIZE	32768
-typedef struct _evapi_client {
+#define EVAPI_IPADDR_SIZE 64
+#define EVAPI_TAG_SIZE 64
+#define CLIENT_BUFFER_SIZE 32768
+typedef struct _evapi_client
+{
 	int connected;
 	int sock;
 	unsigned short af;
 	unsigned short src_port;
 	char src_addr[EVAPI_IPADDR_SIZE];
 	char tag[EVAPI_IPADDR_SIZE];
-	str  stag;
+	str stag;
 	char rbuffer[CLIENT_BUFFER_SIZE];
 	unsigned int rpos;
 } evapi_client_t;
 
-typedef struct _evapi_env {
+typedef struct _evapi_env
+{
 	int eset;
 	int conidx;
 	str msg;
 	struct _evapi_env *next;
 } evapi_env_t;
 
-typedef struct _evapi_msg {
+typedef struct _evapi_msg
+{
 	str data;
 	str tag;
 	int unicast;
 } evapi_msg_t;
 
-typedef struct _evapi_queue {
+typedef struct _evapi_queue
+{
 	gen_lock_t qlock;
 	evapi_env_t *head;
 	evapi_env_t *tail;
 } evapi_queue_t;
 
-#define EVAPI_MAX_CLIENTS	_evapi_max_clients
+#define EVAPI_MAX_CLIENTS _evapi_max_clients
 
 /* last one used for error handling, not a real connected client */
 static evapi_client_t *_evapi_clients = NULL;
 
-typedef struct _evapi_evroutes {
+typedef struct _evapi_evroutes
+{
 	int con_new;
 	str con_new_name;
 	int con_closed;
@@ -111,8 +116,8 @@ static evapi_queue_t *_evapi_queue_packets = NULL;
  */
 int evapi_queue_init(void)
 {
-	_evapi_queue_packets = (evapi_queue_t*)shm_malloc(sizeof(evapi_queue_t));
-	if(_evapi_queue_packets==NULL) {
+	_evapi_queue_packets = (evapi_queue_t *)shm_malloc(sizeof(evapi_queue_t));
+	if(_evapi_queue_packets == NULL) {
 		return -1;
 	}
 	memset(_evapi_queue_packets, 0, sizeof(evapi_queue_t));
@@ -132,14 +137,14 @@ int evapi_queue_add(evapi_env_t *renv)
 	evapi_env_t *nenv;
 	uint32_t ssize;
 
-	LM_DBG("adding message to queue [%.*s]\n",  renv->msg.len,  renv->msg.s);
+	LM_DBG("adding message to queue [%.*s]\n", renv->msg.len, renv->msg.s);
 	ssize = ROUND_POINTER(sizeof(evapi_env_t)) + renv->msg.len + 1;
-	nenv = (evapi_env_t*)shm_malloc(ssize);
-	if(nenv==NULL) {
+	nenv = (evapi_env_t *)shm_malloc(ssize);
+	if(nenv == NULL) {
 		return -1;
 	}
 	memset(nenv, 0, ssize);
-	nenv->msg.s = (char*)nenv + ROUND_POINTER(sizeof(evapi_env_t));
+	nenv->msg.s = (char *)nenv + ROUND_POINTER(sizeof(evapi_env_t));
 	memcpy(nenv->msg.s, renv->msg.s, renv->msg.len);
 	nenv->msg.len = renv->msg.len;
 	nenv->eset = renv->eset;
@@ -161,7 +166,7 @@ int evapi_queue_add(evapi_env_t *renv)
 /**
  *
  */
-evapi_env_t* evapi_queue_get(void)
+evapi_env_t *evapi_queue_get(void)
 {
 	evapi_env_t *renv = NULL;
 
@@ -178,8 +183,9 @@ evapi_env_t* evapi_queue_get(void)
 	}
 	lock_release(&_evapi_queue_packets->qlock);
 
-	if(renv!=NULL) {
-		LM_DBG("getting message from queue [%.*s]\n",  renv->msg.len,  renv->msg.s);
+	if(renv != NULL) {
+		LM_DBG("getting message from queue [%.*s]\n", renv->msg.len,
+				renv->msg.s);
 	}
 
 	return renv;
@@ -193,14 +199,14 @@ int evapi_clients_init(void)
 {
 	int i;
 
-	_evapi_clients = (evapi_client_t*)shm_malloc(sizeof(evapi_client_t)
-			* (EVAPI_MAX_CLIENTS+1));
-	if(_evapi_clients==NULL) {
+	_evapi_clients = (evapi_client_t *)shm_malloc(
+			sizeof(evapi_client_t) * (EVAPI_MAX_CLIENTS + 1));
+	if(_evapi_clients == NULL) {
 		LM_ERR("failed to allocate client structures\n");
 		return -1;
 	}
 	memset(_evapi_clients, 0, sizeof(evapi_client_t) * EVAPI_MAX_CLIENTS);
-	for(i=0; i<EVAPI_MAX_CLIENTS; i++) {
+	for(i = 0; i < EVAPI_MAX_CLIENTS; i++) {
 		_evapi_clients[i].sock = -1;
 	}
 	return 0;
@@ -212,7 +218,7 @@ int evapi_clients_init(void)
  */
 void evapi_env_reset(evapi_env_t *evenv)
 {
-	if(evenv==0)
+	if(evenv == 0)
 		return;
 	memset(evenv, 0, sizeof(evapi_env_t));
 	evenv->conidx = -1;
@@ -228,19 +234,21 @@ void evapi_init_environment(int dformat)
 	_evapi_rts.con_new_name.s = "evapi:connection-new";
 	_evapi_rts.con_new_name.len = strlen(_evapi_rts.con_new_name.s);
 	_evapi_rts.con_new = route_lookup(&event_rt, "evapi:connection-new");
-	if (_evapi_rts.con_new < 0 || event_rt.rlist[_evapi_rts.con_new] == NULL)
+	if(_evapi_rts.con_new < 0 || event_rt.rlist[_evapi_rts.con_new] == NULL)
 		_evapi_rts.con_new = -1;
 
 	_evapi_rts.con_closed_name.s = "evapi:connection-closed";
 	_evapi_rts.con_closed_name.len = strlen(_evapi_rts.con_closed_name.s);
 	_evapi_rts.con_closed = route_lookup(&event_rt, "evapi:connection-closed");
-	if (_evapi_rts.con_closed < 0 || event_rt.rlist[_evapi_rts.con_closed] == NULL)
+	if(_evapi_rts.con_closed < 0
+			|| event_rt.rlist[_evapi_rts.con_closed] == NULL)
 		_evapi_rts.con_closed = -1;
 
 	_evapi_rts.msg_received_name.s = "evapi:message-received";
 	_evapi_rts.msg_received_name.len = strlen(_evapi_rts.msg_received_name.s);
 	_evapi_rts.msg_received = route_lookup(&event_rt, "evapi:message-received");
-	if (_evapi_rts.msg_received < 0 || event_rt.rlist[_evapi_rts.msg_received] == NULL)
+	if(_evapi_rts.msg_received < 0
+			|| event_rt.rlist[_evapi_rts.msg_received] == NULL)
 		_evapi_rts.msg_received = -1;
 
 	_evapi_netstring_format = dformat;
@@ -257,15 +265,17 @@ int evapi_run_cfg_route(evapi_env_t *evenv, int rt, str *rtname)
 	sip_msg_t tmsg;
 	sr_kemi_eng_t *keng = NULL;
 
-	if(evenv==0 || evenv->eset==0) {
+	if(evenv == 0 || evenv->eset == 0) {
 		LM_ERR("evapi env not set\n");
 		return -1;
 	}
 
-	if((rt<0) && (_evapi_event_callback.s==NULL || _evapi_event_callback.len<=0))
+	if((rt < 0)
+			&& (_evapi_event_callback.s == NULL
+					|| _evapi_event_callback.len <= 0))
 		return 0;
 
-	if(faked_msg_get_new(&tmsg)<0) {
+	if(faked_msg_get_new(&tmsg) < 0) {
 		LM_ERR("failed to get a new faked message\n");
 		return -1;
 	}
@@ -274,13 +284,14 @@ int evapi_run_cfg_route(evapi_env_t *evenv, int rt, str *rtname)
 	backup_rt = get_route_type();
 	set_route_type(EVENT_ROUTE);
 	init_run_actions_ctx(&ctx);
-	if(rt>=0) {
+	if(rt >= 0) {
 		run_top_route(event_rt.rlist[rt], fmsg, 0);
 	} else {
 		keng = sr_kemi_eng_get();
-		if(keng!=NULL) {
-			if(sr_kemi_route(keng, fmsg, EVENT_ROUTE,
-						&_evapi_event_callback, rtname)<0) {
+		if(keng != NULL) {
+			if(sr_kemi_route(
+					   keng, fmsg, EVENT_ROUTE, &_evapi_event_callback, rtname)
+					< 0) {
 				LM_ERR("error running event route kemi callback\n");
 			}
 		}
@@ -298,10 +309,9 @@ int evapi_run_cfg_route(evapi_env_t *evenv, int rt, str *rtname)
  */
 int evapi_close_connection(int cidx)
 {
-	if(cidx<0 || cidx>=EVAPI_MAX_CLIENTS || _evapi_clients==NULL)
+	if(cidx < 0 || cidx >= EVAPI_MAX_CLIENTS || _evapi_clients == NULL)
 		return -1;
-	if(_evapi_clients[cidx].connected==1
-			&& _evapi_clients[cidx].sock >= 0) {
+	if(_evapi_clients[cidx].connected == 1 && _evapi_clients[cidx].sock >= 0) {
 		close(_evapi_clients[cidx].sock);
 		_evapi_clients[cidx].connected = 0;
 		_evapi_clients[cidx].sock = -1;
@@ -317,12 +327,12 @@ int evapi_cfg_close(sip_msg_t *msg)
 {
 	evapi_env_t *evenv;
 
-	if(msg==NULL)
+	if(msg == NULL)
 		return -1;
 
 	evenv = evapi_get_msg_env(msg);
 
-	if(evenv==NULL || evenv->conidx<0 || evenv->conidx>=EVAPI_MAX_CLIENTS)
+	if(evenv == NULL || evenv->conidx < 0 || evenv->conidx >= EVAPI_MAX_CLIENTS)
 		return -1;
 	return evapi_close_connection(evenv->conidx);
 }
@@ -330,25 +340,25 @@ int evapi_cfg_close(sip_msg_t *msg)
 /**
  *
  */
-int evapi_set_tag(sip_msg_t* msg, str* stag)
+int evapi_set_tag(sip_msg_t *msg, str *stag)
 {
 	evapi_env_t *evenv;
 
-	if(msg==NULL || stag==NULL || _evapi_clients==NULL)
+	if(msg == NULL || stag == NULL || _evapi_clients == NULL)
 		return -1;
 
 	evenv = evapi_get_msg_env(msg);
 
-	if(evenv==NULL || evenv->conidx<0 || evenv->conidx>=EVAPI_MAX_CLIENTS)
+	if(evenv == NULL || evenv->conidx < 0 || evenv->conidx >= EVAPI_MAX_CLIENTS)
 		return -1;
 
-	if(!(_evapi_clients[evenv->conidx].connected==1
-			&& _evapi_clients[evenv->conidx].sock >= 0)) {
+	if(!(_evapi_clients[evenv->conidx].connected == 1
+			   && _evapi_clients[evenv->conidx].sock >= 0)) {
 		LM_ERR("connection not established\n");
 		return -1;
 	}
 
-	if(stag->len>=EVAPI_TAG_SIZE) {
+	if(stag->len >= EVAPI_TAG_SIZE) {
 		LM_ERR("tag size too big: %d / %d\n", stag->len, EVAPI_TAG_SIZE);
 		return -1;
 	}
@@ -364,7 +374,7 @@ int evapi_set_tag(sip_msg_t* msg, str* stag)
  */
 int evapi_init_notify_sockets(void)
 {
-	if (socketpair(PF_UNIX, SOCK_STREAM, 0, _evapi_notify_sockets) < 0) {
+	if(socketpair(PF_UNIX, SOCK_STREAM, 0, _evapi_notify_sockets) < 0) {
 		LM_ERR("opening notify stream socket pair\n");
 		return -1;
 	}
@@ -402,25 +412,27 @@ int evapi_dispatch_notify(evapi_msg_t *emsg)
 	int n;
 	int wlen;
 
-	if(_evapi_clients==NULL) {
+	if(_evapi_clients == NULL) {
 		return 0;
 	}
 
 	n = 0;
-	for(i=0; i<EVAPI_MAX_CLIENTS; i++) {
-		if(_evapi_clients[i].connected==1 && _evapi_clients[i].sock>=0) {
-			if(emsg->tag.s==NULL || (emsg->tag.len == _evapi_clients[i].stag.len
-						&& strncmp(_evapi_clients[i].stag.s,
-									emsg->tag.s, emsg->tag.len)==0)) {
-				wlen = write(_evapi_clients[i].sock, emsg->data.s,
-						emsg->data.len);
-				if(wlen!=emsg->data.len) {
+	for(i = 0; i < EVAPI_MAX_CLIENTS; i++) {
+		if(_evapi_clients[i].connected == 1 && _evapi_clients[i].sock >= 0) {
+			if(emsg->tag.s == NULL
+					|| (emsg->tag.len == _evapi_clients[i].stag.len
+							&& strncmp(_evapi_clients[i].stag.s, emsg->tag.s,
+									   emsg->tag.len)
+									   == 0)) {
+				wlen = write(
+						_evapi_clients[i].sock, emsg->data.s, emsg->data.len);
+				if(wlen != emsg->data.len) {
 					LM_DBG("failed to write all packet (%d out of %d) on socket"
-							" %d index [%d]\n",
+						   " %d index [%d]\n",
 							wlen, emsg->data.len, _evapi_clients[i].sock, i);
 				}
 				n++;
-				if (emsg->unicast){
+				if(emsg->unicast) {
 					break;
 				}
 			}
@@ -448,20 +460,22 @@ void evapi_recv_client(struct ev_loop *loop, struct ev_io *watcher, int revents)
 		LM_ERR("received invalid event (%d)\n", revents);
 		return;
 	}
-	if(_evapi_clients==NULL) {
+	if(_evapi_clients == NULL) {
 		LM_ERR("no client structures\n");
 		return;
 	}
 
-	for(i=0; i<EVAPI_MAX_CLIENTS; i++) {
-		if(_evapi_clients[i].connected==1 && _evapi_clients[i].sock==watcher->fd) {
+	for(i = 0; i < EVAPI_MAX_CLIENTS; i++) {
+		if(_evapi_clients[i].connected == 1
+				&& _evapi_clients[i].sock == watcher->fd) {
 			break;
 		}
 	}
-	if(i==EVAPI_MAX_CLIENTS) {
+	if(i == EVAPI_MAX_CLIENTS) {
 		LM_ERR("cannot lookup client socket %d\n", watcher->fd);
 		/* try to empty the socket anyhow */
-		rlen = recv(watcher->fd, _evapi_clients[i].rbuffer, CLIENT_BUFFER_SIZE-1, 0);
+		rlen = recv(watcher->fd, _evapi_clients[i].rbuffer,
+				CLIENT_BUFFER_SIZE - 1, 0);
 		return;
 	}
 
@@ -483,110 +497,116 @@ void evapi_recv_client(struct ev_loop *loop, struct ev_io *watcher, int revents)
 		/* client is gone */
 		evenv.eset = 1;
 		evenv.conidx = i;
-		evapi_run_cfg_route(&evenv, _evapi_rts.con_closed,
-				&_evapi_rts.con_closed_name);
+		evapi_run_cfg_route(
+				&evenv, _evapi_rts.con_closed, &_evapi_rts.con_closed_name);
 		_evapi_clients[i].connected = 0;
-		if(_evapi_clients[i].sock>=0) {
+		if(_evapi_clients[i].sock >= 0) {
 			close(_evapi_clients[i].sock);
 		}
 		_evapi_clients[i].sock = -1;
 		_evapi_clients[i].rpos = 0;
 		ev_io_stop(loop, watcher);
 		free(watcher);
-		LM_INFO("client closing connection - pos [%d] addr [%s:%d]\n",
-				i, _evapi_clients[i].src_addr, _evapi_clients[i].src_port);
+		LM_INFO("client closing connection - pos [%d] addr [%s:%d]\n", i,
+				_evapi_clients[i].src_addr, _evapi_clients[i].src_port);
 		return;
 	}
 
-	_evapi_clients[i].rbuffer[_evapi_clients[i].rpos+rlen] = '\0';
+	_evapi_clients[i].rbuffer[_evapi_clients[i].rpos + rlen] = '\0';
 
-	LM_DBG("{%d} [%s:%d] - received [%.*s] (%d) (%d)\n",
-		i, _evapi_clients[i].src_addr, _evapi_clients[i].src_port,
-		(int)rlen, _evapi_clients[i].rbuffer+_evapi_clients[i].rpos,
-		(int)rlen, (int)_evapi_clients[i].rpos);
+	LM_DBG("{%d} [%s:%d] - received [%.*s] (%d) (%d)\n", i,
+			_evapi_clients[i].src_addr, _evapi_clients[i].src_port, (int)rlen,
+			_evapi_clients[i].rbuffer + _evapi_clients[i].rpos, (int)rlen,
+			(int)_evapi_clients[i].rpos);
 	evenv.conidx = i;
 	evenv.eset = 1;
 	if(_evapi_netstring_format) {
 		/* netstring decapsulation */
 		k = 0;
-		while(k<_evapi_clients[i].rpos+rlen) {
+		while(k < _evapi_clients[i].rpos + rlen) {
 			frame.len = 0;
-			while(k<_evapi_clients[i].rpos+rlen) {
-				if(_evapi_clients[i].rbuffer[k]==' '
-						|| _evapi_clients[i].rbuffer[k]=='\t'
-						|| _evapi_clients[i].rbuffer[k]=='\r'
-						|| _evapi_clients[i].rbuffer[k]=='\n')
+			while(k < _evapi_clients[i].rpos + rlen) {
+				if(_evapi_clients[i].rbuffer[k] == ' '
+						|| _evapi_clients[i].rbuffer[k] == '\t'
+						|| _evapi_clients[i].rbuffer[k] == '\r'
+						|| _evapi_clients[i].rbuffer[k] == '\n')
 					k++;
-				else break;
+				else
+					break;
 			}
-			if(k==_evapi_clients[i].rpos+rlen) {
+			if(k == _evapi_clients[i].rpos + rlen) {
 				_evapi_clients[i].rpos = 0;
 				LM_DBG("empty content\n");
 				return;
 			}
 			/* pointer to start of whole frame */
 			sfp = _evapi_clients[i].rbuffer + k;
-			while(k<_evapi_clients[i].rpos+rlen) {
-				if(_evapi_clients[i].rbuffer[k]>='0' && _evapi_clients[i].rbuffer[k]<='9') {
-					frame.len = frame.len*10 + _evapi_clients[i].rbuffer[k] - '0';
+			while(k < _evapi_clients[i].rpos + rlen) {
+				if(_evapi_clients[i].rbuffer[k] >= '0'
+						&& _evapi_clients[i].rbuffer[k] <= '9') {
+					frame.len =
+							frame.len * 10 + _evapi_clients[i].rbuffer[k] - '0';
 				} else {
-					if(_evapi_clients[i].rbuffer[k]==':')
+					if(_evapi_clients[i].rbuffer[k] == ':')
 						break;
 					/* invalid character - discard the rest */
 					_evapi_clients[i].rpos = 0;
-					LM_DBG("invalid char when searching for size [%c] [%.*s] (%d) (%d)\n",
+					LM_DBG("invalid char when searching for size [%c] [%.*s] "
+						   "(%d) (%d)\n",
 							_evapi_clients[i].rbuffer[k],
-							(int)(_evapi_clients[i].rpos+rlen), _evapi_clients[i].rbuffer,
-							(int)(_evapi_clients[i].rpos+rlen), k);
+							(int)(_evapi_clients[i].rpos + rlen),
+							_evapi_clients[i].rbuffer,
+							(int)(_evapi_clients[i].rpos + rlen), k);
 					return;
 				}
 				k++;
 			}
-			if(k==_evapi_clients[i].rpos+rlen || frame.len<=0) {
+			if(k == _evapi_clients[i].rpos + rlen || frame.len <= 0) {
 				LM_DBG("invalid frame len: %d kpos: %d rpos: %u rlen: %lu\n",
 						frame.len, k, _evapi_clients[i].rpos, rlen);
 				_evapi_clients[i].rpos = 0;
 				return;
 			}
-			if(frame.len + k>=_evapi_clients[i].rpos + rlen) {
+			if(frame.len + k >= _evapi_clients[i].rpos + rlen) {
 				/* partial data - shift back in buffer and wait to read more */
 				efp = _evapi_clients[i].rbuffer + _evapi_clients[i].rpos + rlen;
-				if(efp<=sfp) {
+				if(efp <= sfp) {
 					_evapi_clients[i].rpos = 0;
 					LM_DBG("weird - invalid size for residual data\n");
 					return;
 				}
-				_evapi_clients[i].rpos = (unsigned int)(efp-sfp);
-				if(efp-sfp > sfp-_evapi_clients[i].rbuffer) {
-					memcpy(_evapi_clients[i].rbuffer, sfp, _evapi_clients[i].rpos);
+				_evapi_clients[i].rpos = (unsigned int)(efp - sfp);
+				if(efp - sfp > sfp - _evapi_clients[i].rbuffer) {
+					memcpy(_evapi_clients[i].rbuffer, sfp,
+							_evapi_clients[i].rpos);
 				} else {
-					for(k=0; k<_evapi_clients[i].rpos; k++) {
+					for(k = 0; k < _evapi_clients[i].rpos; k++) {
 						_evapi_clients[i].rbuffer[k] = sfp[k];
 					}
 				}
-				LM_DBG("residual data [%.*s] (%d)\n",
-						_evapi_clients[i].rpos, _evapi_clients[i].rbuffer,
-						_evapi_clients[i].rpos);
+				LM_DBG("residual data [%.*s] (%d)\n", _evapi_clients[i].rpos,
+						_evapi_clients[i].rbuffer, _evapi_clients[i].rpos);
 				return;
 			}
 			k++;
 			frame.s = _evapi_clients[i].rbuffer + k;
-			if(frame.s[frame.len]!=',') {
+			if(frame.s[frame.len] != ',') {
 				/* invalid data - discard and reset buffer */
-				LM_DBG("frame size mismatch the ending char (%c): [%.*s] (%d)\n",
+				LM_DBG("frame size mismatch the ending char (%c): [%.*s] "
+					   "(%d)\n",
 						frame.s[frame.len], frame.len, frame.s, frame.len);
-				_evapi_clients[i].rpos = 0 ;
+				_evapi_clients[i].rpos = 0;
 				return;
 			}
 			frame.s[frame.len] = '\0';
-			k += frame.len ;
+			k += frame.len;
 			evenv.msg.s = frame.s;
 			evenv.msg.len = frame.len;
-			if(_evapi_workers<=0) {
+			if(_evapi_workers <= 0) {
 				LM_DBG("executing event route for frame: [%.*s] (%d)\n",
 						frame.len, frame.s, frame.len);
 				evapi_run_cfg_route(&evenv, _evapi_rts.msg_received,
-					&_evapi_rts.msg_received_name);
+						&_evapi_rts.msg_received_name);
 			} else {
 				LM_DBG("queueing event route for frame: [%.*s] (%d)\n",
 						frame.len, frame.s, frame.len);
@@ -594,13 +614,13 @@ void evapi_recv_client(struct ev_loop *loop, struct ev_io *watcher, int revents)
 			}
 			k++;
 		}
-		_evapi_clients[i].rpos = 0 ;
+		_evapi_clients[i].rpos = 0;
 	} else {
 		evenv.msg.s = _evapi_clients[i].rbuffer;
 		evenv.msg.len = rlen;
-		if(_evapi_workers<=0) {
+		if(_evapi_workers <= 0) {
 			evapi_run_cfg_route(&evenv, _evapi_rts.msg_received,
-				&_evapi_rts.msg_received_name);
+					&_evapi_rts.msg_received_name);
 		} else {
 			evapi_queue_add(&evenv);
 		}
@@ -610,7 +630,8 @@ void evapi_recv_client(struct ev_loop *loop, struct ev_io *watcher, int revents)
 /**
  *
  */
-void evapi_accept_client(struct ev_loop *loop, struct ev_io *watcher, int revents)
+void evapi_accept_client(
+		struct ev_loop *loop, struct ev_io *watcher, int revents)
 {
 	struct sockaddr caddr;
 	socklen_t clen = sizeof(caddr);
@@ -621,12 +642,12 @@ void evapi_accept_client(struct ev_loop *loop, struct ev_io *watcher, int revent
 	int optval;
 	socklen_t optlen;
 
-	if(_evapi_clients==NULL) {
+	if(_evapi_clients == NULL) {
 		LM_ERR("no client structures\n");
 		return;
 	}
-	evapi_client = (struct ev_io*) malloc (sizeof(struct ev_io));
-	if(evapi_client==NULL) {
+	evapi_client = (struct ev_io *)malloc(sizeof(struct ev_io));
+	if(evapi_client == NULL) {
 		LM_ERR("no more memory\n");
 		return;
 	}
@@ -642,28 +663,32 @@ void evapi_accept_client(struct ev_loop *loop, struct ev_io *watcher, int revent
 	/* accept new client connection */
 	csock = accept(watcher->fd, (struct sockaddr *)&caddr, &clen);
 
-	if (csock < 0) {
-		LM_ERR("cannot accept the client '%s' err='%d'\n", gai_strerror(csock), csock);
+	if(csock < 0) {
+		LM_ERR("cannot accept the client '%s' err='%d'\n", gai_strerror(csock),
+				csock);
 		free(evapi_client);
 		return;
 	}
-	for(i=0; i<EVAPI_MAX_CLIENTS; i++) {
-		if(_evapi_clients[i].connected==0) {
-			if (caddr.sa_family == AF_INET) {
-				_evapi_clients[i].src_port = ntohs(((struct sockaddr_in*)&caddr)->sin_port);
-				if(inet_ntop(AF_INET, &((struct sockaddr_in*)&caddr)->sin_addr,
-							_evapi_clients[i].src_addr,
-							EVAPI_IPADDR_SIZE)==NULL) {
+	for(i = 0; i < EVAPI_MAX_CLIENTS; i++) {
+		if(_evapi_clients[i].connected == 0) {
+			if(caddr.sa_family == AF_INET) {
+				_evapi_clients[i].src_port =
+						ntohs(((struct sockaddr_in *)&caddr)->sin_port);
+				if(inet_ntop(AF_INET, &((struct sockaddr_in *)&caddr)->sin_addr,
+						   _evapi_clients[i].src_addr, EVAPI_IPADDR_SIZE)
+						== NULL) {
 					LM_ERR("cannot convert ipv4 address\n");
 					close(csock);
 					free(evapi_client);
 					return;
 				}
 			} else {
-				_evapi_clients[i].src_port = ntohs(((struct sockaddr_in6*)&caddr)->sin6_port);
-				if(inet_ntop(AF_INET6, &((struct sockaddr_in6*)&caddr)->sin6_addr,
-							_evapi_clients[i].src_addr,
-							EVAPI_IPADDR_SIZE)==NULL) {
+				_evapi_clients[i].src_port =
+						ntohs(((struct sockaddr_in6 *)&caddr)->sin6_port);
+				if(inet_ntop(AF_INET6,
+						   &((struct sockaddr_in6 *)&caddr)->sin6_addr,
+						   _evapi_clients[i].src_addr, EVAPI_IPADDR_SIZE)
+						== NULL) {
 					LM_ERR("cannot convert ipv6 address\n");
 					close(csock);
 					free(evapi_client);
@@ -672,8 +697,8 @@ void evapi_accept_client(struct ev_loop *loop, struct ev_io *watcher, int revent
 			}
 			optval = 1;
 			optlen = sizeof(optval);
-			if(setsockopt(csock, SOL_SOCKET, SO_KEEPALIVE,
-						&optval, optlen) < 0) {
+			if(setsockopt(csock, SOL_SOCKET, SO_KEEPALIVE, &optval, optlen)
+					< 0) {
 				LM_WARN("failed to enable keepalive on socket %d\n", csock);
 			}
 			_evapi_clients[i].connected = 1;
@@ -682,7 +707,7 @@ void evapi_accept_client(struct ev_loop *loop, struct ev_io *watcher, int revent
 			break;
 		}
 	}
-	if(i>=EVAPI_MAX_CLIENTS) {
+	if(i >= EVAPI_MAX_CLIENTS) {
 		LM_ERR("too many clients\n");
 		close(csock);
 		free(evapi_client);
@@ -723,15 +748,15 @@ void evapi_recv_notify(struct ev_loop *loop, struct ev_io *watcher, int revents)
 	cfg_update();
 
 	/* read message from client */
-	rlen = read(watcher->fd, &emsg, sizeof(evapi_msg_t*));
+	rlen = read(watcher->fd, &emsg, sizeof(evapi_msg_t *));
 
-	if(rlen != sizeof(evapi_msg_t*) || emsg==NULL) {
+	if(rlen != sizeof(evapi_msg_t *) || emsg == NULL) {
 		LM_ERR("cannot read the sip worker message\n");
 		return;
 	}
 
-	LM_DBG("received [%p] [%.*s] (%d)\n", (void*)emsg,
-			emsg->data.len, emsg->data.s, emsg->data.len);
+	LM_DBG("received [%p] [%.*s] (%d)\n", (void *)emsg, emsg->data.len,
+			emsg->data.s, emsg->data.len);
 	evapi_dispatch_notify(emsg);
 	shm_free(emsg);
 }
@@ -753,29 +778,29 @@ int evapi_run_dispatcher(char *laddr, int lport)
 
 	LM_DBG("starting dispatcher processing\n");
 
-	if(_evapi_clients==NULL) {
+	if(_evapi_clients == NULL) {
 		LM_ERR("client structures not initialized\n");
 		exit(-1);
 	}
 
 	loop = ev_default_loop(0);
 
-	if(loop==NULL) {
+	if(loop == NULL) {
 		LM_ERR("cannot get libev loop\n");
 		return -1;
 	}
 
 	memset(&ai_hints, 0, sizeof(struct addrinfo));
 	ai_hints.ai_family = AF_UNSPEC;		/* allow IPv4 or IPv6 */
-	ai_hints.ai_socktype = SOCK_STREAM;	/* stream socket */
+	ai_hints.ai_socktype = SOCK_STREAM; /* stream socket */
 	ai_ret = getaddrinfo(laddr, int2str(lport, NULL), &ai_hints, &ai_res);
-	if (ai_ret != 0) {
+	if(ai_ret != 0) {
 		LM_ERR("getaddrinfo failed: %d %s\n", ai_ret, gai_strerror(ai_ret));
 		return -1;
 	}
-	evapi_srv_sock = socket(ai_res->ai_family, ai_res->ai_socktype,
-			ai_res->ai_protocol);
-	if( evapi_srv_sock < 0 ) {
+	evapi_srv_sock =
+			socket(ai_res->ai_family, ai_res->ai_socktype, ai_res->ai_protocol);
+	if(evapi_srv_sock < 0) {
 		LM_ERR("cannot create server socket (family %d)\n", ai_res->ai_family);
 		freeaddrinfo(ai_res);
 		return -1;
@@ -783,13 +808,13 @@ int evapi_run_dispatcher(char *laddr, int lport)
 
 	/* set non-blocking flag */
 	fflags = fcntl(evapi_srv_sock, F_GETFL);
-	if(fflags<0) {
+	if(fflags < 0) {
 		LM_ERR("failed to get the srv socket flags\n");
 		close(evapi_srv_sock);
 		freeaddrinfo(ai_res);
 		return -1;
 	}
-	if (fcntl(evapi_srv_sock, F_SETFL, fflags | O_NONBLOCK)<0) {
+	if(fcntl(evapi_srv_sock, F_SETFL, fflags | O_NONBLOCK) < 0) {
 		LM_ERR("failed to set srv socket flags\n");
 		close(evapi_srv_sock);
 		freeaddrinfo(ai_res);
@@ -801,33 +826,35 @@ int evapi_run_dispatcher(char *laddr, int lport)
 	 * re-binding.
 	 */
 
-	if(setsockopt(evapi_srv_sock, SOL_SOCKET, SO_REUSEADDR,
-		&yes_true, sizeof(int)) < 0) {
+	if(setsockopt(
+			   evapi_srv_sock, SOL_SOCKET, SO_REUSEADDR, &yes_true, sizeof(int))
+			< 0) {
 		LM_ERR("cannot set SO_REUSEADDR option on descriptor\n");
 		close(evapi_srv_sock);
 		freeaddrinfo(ai_res);
 		return -1;
 	}
 
-	if (bind(evapi_srv_sock, ai_res->ai_addr, ai_res->ai_addrlen) < 0) {
+	if(bind(evapi_srv_sock, ai_res->ai_addr, ai_res->ai_addrlen) < 0) {
 		LM_ERR("cannot bind to local address and port [%s:%d]\n", laddr, lport);
 		close(evapi_srv_sock);
 		freeaddrinfo(ai_res);
 		return -1;
 	}
 	freeaddrinfo(ai_res);
-	if (listen(evapi_srv_sock, 4) < 0) {
+	if(listen(evapi_srv_sock, 4) < 0) {
 		LM_ERR("listen error\n");
 		close(evapi_srv_sock);
 		return -1;
 	}
 	ev_io_init(&io_server, evapi_accept_client, evapi_srv_sock, EV_READ);
 	ev_io_start(loop, &io_server);
-	ev_io_init(&io_notify, evapi_recv_notify, _evapi_notify_sockets[0], EV_READ);
+	ev_io_init(
+			&io_notify, evapi_recv_notify, _evapi_notify_sockets[0], EV_READ);
 	ev_io_start(loop, &io_notify);
 
 	while(1) {
-		ev_loop (loop, 0);
+		ev_loop(loop, 0);
 	}
 
 	return 0;
@@ -850,8 +877,8 @@ int evapi_run_worker(int prank)
 	while(1) {
 		renv = evapi_queue_get();
 		if(renv != NULL) {
-			LM_DBG("processing task: %p [%.*s]\n", renv,
-					renv->msg.len, ZSW(renv->msg.s));
+			LM_DBG("processing task: %p [%.*s]\n", renv, renv->msg.len,
+					ZSW(renv->msg.s));
 			evapi_run_cfg_route(renv, _evapi_rts.msg_received,
 					&_evapi_rts.msg_received_name);
 			shm_free(renv);
@@ -876,57 +903,56 @@ int _evapi_relay(str *evdata, str *ctag, int unicast)
 	int sbsize;
 	evapi_msg_t *emsg;
 
-	LM_DBG("relaying event data [%.*s] (%d)\n",
-			evdata->len, evdata->s, evdata->len);
+	LM_DBG("relaying event data [%.*s] (%d)\n", evdata->len, evdata->s,
+			evdata->len);
 
 	sbsize = evdata->len;
 	len = sizeof(evapi_msg_t)
-		+ ((sbsize + 32 + ((ctag && ctag->len>0)?(ctag->len+2):0)) * sizeof(char));
-	emsg = (evapi_msg_t*)shm_malloc(len);
-	if(emsg==NULL) {
+		  + ((sbsize + 32 + ((ctag && ctag->len > 0) ? (ctag->len + 2) : 0))
+				  * sizeof(char));
+	emsg = (evapi_msg_t *)shm_malloc(len);
+	if(emsg == NULL) {
 		LM_ERR("no more shared memory\n");
 		return -1;
 	}
 	memset(emsg, 0, len);
-	emsg->data.s = (char*)emsg + sizeof(evapi_msg_t);
+	emsg->data.s = (char *)emsg + sizeof(evapi_msg_t);
 	if(_evapi_netstring_format) {
 		/* netstring encapsulation */
-		emsg->data.len = snprintf(emsg->data.s, sbsize+32,
-				EVAPI_RELAY_FORMAT,
+		emsg->data.len = snprintf(emsg->data.s, sbsize + 32, EVAPI_RELAY_FORMAT,
 				sbsize, evdata->len, evdata->s);
 	} else {
-		emsg->data.len = snprintf(emsg->data.s, sbsize+32,
-				"%.*s",
-				evdata->len, evdata->s);
+		emsg->data.len = snprintf(
+				emsg->data.s, sbsize + 32, "%.*s", evdata->len, evdata->s);
 	}
-	if(emsg->data.len<=0 || emsg->data.len>sbsize+32) {
+	if(emsg->data.len <= 0 || emsg->data.len > sbsize + 32) {
 		shm_free(emsg);
 		LM_ERR("cannot serialize event\n");
 		return -1;
 	}
-	if(ctag && ctag->len>0) {
+	if(ctag && ctag->len > 0) {
 		emsg->tag.s = emsg->data.s + sbsize + 32;
 		strncpy(emsg->tag.s, ctag->s, ctag->len);
 		emsg->tag.len = ctag->len;
 	}
 
-	if (unicast){
+	if(unicast) {
 		emsg->unicast = unicast;
 	}
 
-	LM_DBG("sending [%p] [%.*s] (%d)\n", (void*)emsg, emsg->data.len,
+	LM_DBG("sending [%p] [%.*s] (%d)\n", (void *)emsg, emsg->data.len,
 			emsg->data.s, emsg->data.len);
-	if(_evapi_notify_sockets[1]!=-1) {
-		len = write(_evapi_notify_sockets[1], &emsg, sizeof(evapi_msg_t*));
-		if(len<=0) {
+	if(_evapi_notify_sockets[1] != -1) {
+		len = write(_evapi_notify_sockets[1], &emsg, sizeof(evapi_msg_t *));
+		if(len <= 0) {
 			shm_free(emsg);
 			LM_ERR("failed to pass the pointer to evapi dispatcher\n");
 			return -1;
 		}
 	} else {
 		cfg_update();
-		LM_DBG("dispatching [%p] [%.*s] (%d)\n", (void*)emsg,
-				emsg->data.len, emsg->data.s, emsg->data.len);
+		LM_DBG("dispatching [%p] [%.*s] (%d)\n", (void *)emsg, emsg->data.len,
+				emsg->data.s, emsg->data.len);
 		if(evapi_dispatch_notify(emsg) == 0) {
 			shm_free(emsg);
 			LM_WARN("message not delivered - no client connected\n");
@@ -948,14 +974,16 @@ int evapi_relay(str *evdata)
 /**
  *
  */
-int evapi_relay_multicast(str *evdata, str *ctag){
+int evapi_relay_multicast(str *evdata, str *ctag)
+{
 	return _evapi_relay(evdata, ctag, 0);
 }
 
 /**
  *
  */
-int evapi_relay_unicast(str *evdata, str *ctag){
+int evapi_relay_unicast(str *evdata, str *ctag)
+{
 	return _evapi_relay(evdata, ctag, 1);
 }
 
@@ -1005,28 +1033,30 @@ int evapi_relay(str *event, str *data)
  */
 int pv_parse_evapi_name(pv_spec_t *sp, str *in)
 {
-	if(sp==NULL || in==NULL || in->len<=0)
+	if(sp == NULL || in == NULL || in->len <= 0)
 		return -1;
 
-	switch(in->len)
-	{
+	switch(in->len) {
 		case 3:
-			if(strncmp(in->s, "msg", 3)==0)
+			if(strncmp(in->s, "msg", 3) == 0)
 				sp->pvp.pvn.u.isname.name.n = 1;
-			else goto error;
-		break;
+			else
+				goto error;
+			break;
 		case 6:
-			if(strncmp(in->s, "conidx", 6)==0)
+			if(strncmp(in->s, "conidx", 6) == 0)
 				sp->pvp.pvn.u.isname.name.n = 0;
-			else goto error;
-		break;
+			else
+				goto error;
+			break;
 		case 7:
-			if(strncmp(in->s, "srcaddr", 7)==0)
+			if(strncmp(in->s, "srcaddr", 7) == 0)
 				sp->pvp.pvn.u.isname.name.n = 2;
-			else if(strncmp(in->s, "srcport", 7)==0)
+			else if(strncmp(in->s, "srcport", 7) == 0)
 				sp->pvp.pvn.u.isname.name.n = 3;
-			else goto error;
-		break;
+			else
+				goto error;
+			break;
 		default:
 			goto error;
 	}
@@ -1047,35 +1077,34 @@ int pv_get_evapi(sip_msg_t *msg, pv_param_t *param, pv_value_t *res)
 {
 	evapi_env_t *evenv;
 
-	if(param==NULL || res==NULL)
+	if(param == NULL || res == NULL)
 		return -1;
 
-	if(_evapi_clients==NULL) {
+	if(_evapi_clients == NULL) {
 		return pv_get_null(msg, param, res);
 	}
 	evenv = evapi_get_msg_env(msg);
 
-	if(evenv==NULL || evenv->conidx<0 || evenv->conidx>=EVAPI_MAX_CLIENTS)
+	if(evenv == NULL || evenv->conidx < 0 || evenv->conidx >= EVAPI_MAX_CLIENTS)
 		return pv_get_null(msg, param, res);
 
-	if(_evapi_clients[evenv->conidx].connected==0
+	if(_evapi_clients[evenv->conidx].connected == 0
 			&& _evapi_clients[evenv->conidx].sock < 0)
 		return pv_get_null(msg, param, res);
 
-	switch(param->pvn.u.isname.name.n)
-	{
+	switch(param->pvn.u.isname.name.n) {
 		case 0:
 			return pv_get_sintval(msg, param, res, evenv->conidx);
 		case 1:
-			if(evenv->msg.s==NULL)
+			if(evenv->msg.s == NULL)
 				return pv_get_null(msg, param, res);
 			return pv_get_strval(msg, param, res, &evenv->msg);
 		case 2:
-			return pv_get_strzval(msg, param, res,
-					_evapi_clients[evenv->conidx].src_addr);
+			return pv_get_strzval(
+					msg, param, res, _evapi_clients[evenv->conidx].src_addr);
 		case 3:
-			return pv_get_sintval(msg, param, res,
-					_evapi_clients[evenv->conidx].src_port);
+			return pv_get_sintval(
+					msg, param, res, _evapi_clients[evenv->conidx].src_port);
 		default:
 			return pv_get_null(msg, param, res);
 	}
@@ -1086,8 +1115,7 @@ int pv_get_evapi(sip_msg_t *msg, pv_param_t *param, pv_value_t *res)
 /**
  *
  */
-int pv_set_evapi(sip_msg_t *msg, pv_param_t *param, int op,
-		pv_value_t *val)
+int pv_set_evapi(sip_msg_t *msg, pv_param_t *param, int op, pv_value_t *val)
 {
 	return 0;
 }
