@@ -66,16 +66,19 @@ int http_client_query_c(struct sip_msg *_m, char *_url, str *_dst, char *_post,
  * (first body line of reply) to pvar.
  */
 int http_client_request(sip_msg_t *_m, char *_url, str *_dst, char *_body,
-		char *_hdrs, char *_met);
+		char *_hdrs, char *_met, unsigned int _httpver);
 
 /*
  * Performs http request and saves possible result
  * (first body line of reply) to pvar.
  */
 int http_client_request_c(sip_msg_t *_m, char *_url, str *_dst, char *_body,
-		char *_ctype, char *_hdrs, char *_met);
+		char *_ctype, char *_hdrs, char *_met, unsigned int _httpver);
 
 
 char *http_get_content_type(const str *connection);
 
+int http_client_response_headers_get(str *hname, str *hbody);
+void http_client_response_headers_reset(void);
+
 #endif /* CURL_FUNCTIONS_H */
