@@ -51,7 +51,7 @@ static mq_pv_t *_mq_pv_list = NULL;
  */
 int mq_head_defined(void)
 {
-	if(_mq_head_list!=NULL)
+	if(_mq_head_list != NULL)
 		return 1;
 	return 0;
 }
@@ -67,18 +67,16 @@ void mq_destroy(void)
 	mq_head_t *mh1 = NULL;
 	mq_pv_t *mp1 = NULL;
 	mq_item_t *mi1 = NULL;
-	
+
 	mh = _mq_head_list;
-	while(mh!=NULL)
-	{
-		if(mh->dbmode == 1 || mh->dbmode == 3)
-		{
-			LM_INFO("mqueue[%.*s] dbmode[%d]\n", mh->name.len, mh->name.s, mh->dbmode);
+	while(mh != NULL) {
+		if(mh->dbmode == 1 || mh->dbmode == 3) {
+			LM_INFO("mqueue[%.*s] dbmode[%d]\n", mh->name.len, mh->name.s,
+					mh->dbmode);
 			mqueue_db_save_queue(&mh->name);
 		}
 		mi = mh->ifirst;
-		while(mi!=NULL)
-		{
+		while(mi != NULL) {
 			mi1 = mi;
 			mi = mi->next;
 			shm_free(mi1);
@@ -90,8 +88,7 @@ void mq_destroy(void)
 	}
 	_mq_head_list = 0;
 	mp = _mq_pv_list;
-	while(mp!=NULL)
-	{
+	while(mp != NULL) {
 		mp1 = mp;
 		mp = mp->next;
 		pkg_free(mp1);
@@ -107,50 +104,44 @@ int mq_head_add(str *name, int msize, int addmode)
 	mq_pv_t *mp = NULL;
 	int len;
 
-	if(!shm_initialized())
-	{
+	if(!shm_initialized()) {
 		LM_ERR("shm not initialized - cannot define mqueue now\n");
 		return 0;
 	}
 
 	mh = _mq_head_list;
-	while(mh!=NULL)
-	{
+	while(mh != NULL) {
 		if(name->len == mh->name.len
-				&& strncmp(mh->name.s, name->s, name->len)==0)
-		{
+				&& strncmp(mh->name.s, name->s, name->len) == 0) {
 			LM_ERR("mqueue redefined: %.*s\n", name->len, name->s);
 			return -1;
 		}
 		mh = mh->next;
 	}
 
-	mp = (mq_pv_t*)pkg_malloc(sizeof(mq_pv_t));
-	if(mp==NULL)
-	{
+	mp = (mq_pv_t *)pkg_malloc(sizeof(mq_pv_t));
+	if(mp == NULL) {
 		LM_ERR("no more pkg for: %.*s\n", name->len, name->s);
 		return -1;
 	}
 	memset(mp, 0, sizeof(mq_pv_t));
 
 	len = sizeof(mq_head_t) + name->len + 1;
-	mh = (mq_head_t*)shm_malloc(len);
-	if(mh==NULL)
-	{
+	mh = (mq_head_t *)shm_malloc(len);
+	if(mh == NULL) {
 		LM_ERR("no more shm for: %.*s\n", name->len, name->s);
 		pkg_free(mp);
 		return -1;
 	}
 	memset(mh, 0, len);
-	if (lock_init(&mh->lock)==0 )
-	{
+	if(lock_init(&mh->lock) == 0) {
 		LM_CRIT("failed to init lock\n");
 		pkg_free(mp);
 		shm_free(mh);
 		return -1;
 	}
 
-	mh->name.s = (char*)mh + sizeof(mq_head_t);
+	mh->name.s = (char *)mh + sizeof(mq_head_t);
 	memcpy(mh->name.s, name->s, name->len);
 	mh->name.len = name->len;
 	mh->name.s[name->len] = '\0';
@@ -174,14 +165,12 @@ mq_head_t *mq_head_get(str *name)
 	mq_head_t *mh = NULL;
 
 	mh = _mq_head_list;
-	if (!name) {
+	if(!name) {
 		return mh;
 	}
-	while(mh!=NULL)
-	{
+	while(mh != NULL) {
 		if(name->len == mh->name.len
-				&& strncmp(mh->name.s, name->s, name->len)==0)
-		{
+				&& strncmp(mh->name.s, name->s, name->len) == 0) {
 			return mh;
 		}
 		mh = mh->next;
@@ -197,11 +186,9 @@ int mq_set_dbmode(str *name, int dbmode)
 	mq_head_t *mh = NULL;
 
 	mh = _mq_head_list;
-	while(mh!=NULL)
-	{
+	while(mh != NULL) {
 		if(name->len == mh->name.len
-				&& strncmp(mh->name.s, name->s, name->len)==0)
-		{
+				&& strncmp(mh->name.s, name->s, name->len) == 0) {
 			mh->dbmode = dbmode;
 			return 0;
 		}
@@ -218,10 +205,9 @@ mq_pv_t *mq_pv_get(str *name)
 	mq_pv_t *mp = NULL;
 
 	mp = _mq_pv_list;
-	while(mp!=NULL)
-	{
-		if(mp->name->len==name->len
-				&& strncmp(mp->name->s, name->s, name->len)==0)
+	while(mp != NULL) {
+		if(mp->name->len == name->len
+				&& strncmp(mp->name->s, name->s, name->len) == 0)
 			return mp;
 		mp = mp->next;
 	}
@@ -237,20 +223,18 @@ int mq_head_fetch(str *name)
 	mq_pv_t *mp = NULL;
 
 	mp = mq_pv_get(name);
-	if(mp==NULL)
+	if(mp == NULL)
 		return -1;
-	if(mp->item!=NULL)
-	{
+	if(mp->item != NULL) {
 		shm_free(mp->item);
 		mp->item = NULL;
 	}
 	mh = mq_head_get(name);
-	if(mh==NULL)
+	if(mh == NULL)
 		return -1;
 	lock_get(&mh->lock);
 
-	if(mh->ifirst==NULL)
-	{
+	if(mh->ifirst == NULL) {
 		/* empty queue */
 		lock_release(&mh->lock);
 		return -2;
@@ -258,7 +242,7 @@ int mq_head_fetch(str *name)
 
 	mp->item = mh->ifirst;
 	mh->ifirst = mh->ifirst->next;
-	if(mh->ifirst==NULL) {
+	if(mh->ifirst == NULL) {
 		mh->ilast = NULL;
 	}
 	mh->csize--;
@@ -275,10 +259,9 @@ void mq_pv_free(str *name)
 	mq_pv_t *mp = NULL;
 
 	mp = mq_pv_get(name);
-	if(mp==NULL)
+	if(mp == NULL)
 		return;
-	if(mp->item!=NULL)
-	{
+	if(mp->item != NULL) {
 		shm_free(mp->item);
 		mp->item = NULL;
 	}
@@ -297,33 +280,33 @@ int mq_item_add(str *qname, str *key, str *val)
 	int len;
 
 	mh = mq_head_get(qname);
-	if(mh==NULL)
-	{
+	if(mh == NULL) {
 		LM_ERR("mqueue not found: %.*s\n", qname->len, qname->s);
 		return -1;
 	}
 
-	if (mh->addmode == 1 || mh->addmode == 2) {
+	if(mh->addmode == 1 || mh->addmode == 2) {
 		lock_get(&mh->lock);
 		oplock = 1;
 		miter = mh->ifirst;
 		miter_prev = mh->ifirst;
-		while (miter) {
+		while(miter) {
 			// found mqueue item
-			if (miter->key.len == key->len && strncmp(miter->key.s, key->s, key->len) == 0) {
+			if(miter->key.len == key->len
+					&& strncmp(miter->key.s, key->s, key->len) == 0) {
 				// mode unique and keep oldest: just return
-				if (mh->addmode == 1) {
+				if(mh->addmode == 1) {
 					lock_release(&mh->lock);
 					return 0;
 				}
 
 				// mode unique and keep newest: free oldest and further add newest
-				if (miter == mh->ifirst && miter == mh->ilast) {
+				if(miter == mh->ifirst && miter == mh->ilast) {
 					mh->ifirst = NULL;
 					mh->ilast = NULL;
-				} else if (miter == mh->ifirst) {
+				} else if(miter == mh->ifirst) {
 					mh->ifirst = miter->next;
-				} else if (miter == mh->ilast) {
+				} else if(miter == mh->ilast) {
 					mh->ilast = miter_prev;
 					mh->ilast->next = NULL;
 				} else {
@@ -342,9 +325,8 @@ int mq_item_add(str *qname, str *key, str *val)
 
 	// mode default
 	len = sizeof(mq_item_t) + key->len + val->len + 2;
-	mi = (mq_item_t*)shm_malloc(len);
-	if(mi==NULL)
-	{
+	mi = (mq_item_t *)shm_malloc(len);
+	if(mi == NULL) {
 		LM_ERR("no more shm to add to: %.*s\n", qname->len, qname->s);
 		if(oplock) {
 			lock_release(&mh->lock);
@@ -352,7 +334,7 @@ int mq_item_add(str *qname, str *key, str *val)
 		return -1;
 	}
 	memset(mi, 0, len);
-	mi->key.s = (char*)mi + sizeof(mq_item_t);
+	mi->key.s = (char *)mi + sizeof(mq_item_t);
 	memcpy(mi->key.s, key->s, key->len);
 	mi->key.len = key->len;
 	mi->key.s[key->len] = '\0';
@@ -362,11 +344,10 @@ int mq_item_add(str *qname, str *key, str *val)
 	mi->val.len = val->len;
 	mi->val.s[val->len] = '\0';
 
-	if(oplock==0) {
+	if(oplock == 0) {
 		lock_get(&mh->lock);
 	}
-	if(mh->ifirst==NULL)
-	{
+	if(mh->ifirst == NULL) {
 		mh->ifirst = mi;
 		mh->ilast = mi;
 	} else {
@@ -374,12 +355,10 @@ int mq_item_add(str *qname, str *key, str *val)
 		mh->ilast = mi;
 	}
 	mh->csize++;
-	if(mh->msize>0 && mh->csize>mh->msize)
-	{
+	if(mh->msize > 0 && mh->csize > mh->msize) {
 		mi = mh->ifirst;
 		mh->ifirst = mh->ifirst->next;
-		if(mh->ifirst==NULL)
-		{
+		if(mh->ifirst == NULL) {
 			mh->ilast = NULL;
 		}
 		mh->csize--;
@@ -406,29 +385,24 @@ str *pv_get_mq_name(sip_msg_t *msg, str *in)
 	pv_spec_t *pvs;
 	pv_value_t pvv;
 
-	if (in->s[0] != '$')
+	if(in->s[0] != '$')
 		return in;
-	else
-	{
-		if (pv_locate_name(in) != in->len)
-		{
+	else {
+		if(pv_locate_name(in) != in->len) {
 			LM_ERR("invalid pv [%.*s]\n", in->len, in->s);
 			return NULL;
 		}
-		if ((pvs = pv_cache_get(in)) == NULL)
-		{
+		if((pvs = pv_cache_get(in)) == NULL) {
 			LM_ERR("failed to get pv spec for [%.*s]\n", in->len, in->s);
 			return NULL;
 		}
 
 		memset(&pvv, 0, sizeof(pv_value_t));
-		if (msg==NULL && faked_msg_init() < 0)
-		{
+		if(msg == NULL && faked_msg_init() < 0) {
 			LM_ERR("faked_msg_init() failed\n");
 			return NULL;
 		}
-		if (pv_get_spec_value((msg)?msg:faked_msg_next(), pvs, &pvv) != 0)
-		{
+		if(pv_get_spec_value((msg) ? msg : faked_msg_next(), pvs, &pvv) != 0) {
 			LM_ERR("failed to get pv value for [%.*s]\n", in->len, in->s);
 			return NULL;
 		}
@@ -442,26 +416,23 @@ str *pv_get_mq_name(sip_msg_t *msg, str *in)
 /**
  *
  */
-int pv_get_mqk(struct sip_msg *msg, pv_param_t *param,
-		pv_value_t *res)
+int pv_get_mqk(struct sip_msg *msg, pv_param_t *param, pv_value_t *res)
 {
 	mq_pv_t *mp = NULL;
 	str *in = pv_get_mq_name(msg, &param->pvn.u.isname.name.s);
 
-	if (in == NULL)
-	{
+	if(in == NULL) {
 		LM_ERR("failed to get mq name\n");
 		return -1;
 	}
 
-	if (mq_head_get(in) == NULL)
-	{
+	if(mq_head_get(in) == NULL) {
 		LM_ERR("mqueue not found: %.*s\n", in->len, in->s);
 		return -1;
 	}
 
 	mp = mq_pv_get(in);
-	if(mp==NULL || mp->item==NULL || mp->item->key.len<=0)
+	if(mp == NULL || mp->item == NULL || mp->item->key.len <= 0)
 		return pv_get_null(msg, param, res);
 	return pv_get_strval(msg, param, res, &mp->item->key);
 }
@@ -469,18 +440,17 @@ int pv_get_mqk(struct sip_msg *msg, pv_param_t *param,
 /**
  *
  */
-str* get_mqk(str *in)
+str *get_mqk(str *in)
 {
 	mq_pv_t *mp = NULL;
 
-	if (mq_head_get(in) == NULL)
-	{
+	if(mq_head_get(in) == NULL) {
 		LM_ERR("mqueue not found: %.*s\n", in->len, in->s);
 		return NULL;
 	}
 
 	mp = mq_pv_get(in);
-	if(mp==NULL || mp->item==NULL || mp->item->key.len<=0)
+	if(mp == NULL || mp->item == NULL || mp->item->key.len <= 0)
 		return NULL;
 	return &mp->item->key;
 }
@@ -488,18 +458,17 @@ str* get_mqk(str *in)
 /**
  *
  */
-str* get_mqv(str *in)
+str *get_mqv(str *in)
 {
 	mq_pv_t *mp = NULL;
 
-	if (mq_head_get(in) == NULL)
-	{
+	if(mq_head_get(in) == NULL) {
 		LM_ERR("mqueue not found: %.*s\n", in->len, in->s);
 		return NULL;
 	}
 
 	mp = mq_pv_get(in);
-	if(mp==NULL || mp->item==NULL || mp->item->val.len<=0)
+	if(mp == NULL || mp->item == NULL || mp->item->val.len <= 0)
 		return NULL;
 	return &mp->item->val;
 }
@@ -507,26 +476,23 @@ str* get_mqv(str *in)
 /**
  *
  */
-int pv_get_mqv(struct sip_msg *msg, pv_param_t *param,
-		pv_value_t *res)
+int pv_get_mqv(struct sip_msg *msg, pv_param_t *param, pv_value_t *res)
 {
 	mq_pv_t *mp = NULL;
 	str *in = pv_get_mq_name(msg, &param->pvn.u.isname.name.s);
 
-	if (in == NULL)
-	{
+	if(in == NULL) {
 		LM_ERR("failed to get mq name\n");
 		return -1;
 	}
 
-	if (mq_head_get(in) == NULL)
-	{
+	if(mq_head_get(in) == NULL) {
 		LM_ERR("mqueue not found: %.*s\n", in->len, in->s);
 		return -1;
 	}
 
 	mp = mq_pv_get(in);
-	if(mp==NULL || mp->item==NULL || mp->item->val.len<=0)
+	if(mp == NULL || mp->item == NULL || mp->item->val.len <= 0)
 		return pv_get_null(msg, param, res);
 	return pv_get_strval(msg, param, res, &mp->item->val);
 }
@@ -534,22 +500,19 @@ int pv_get_mqv(struct sip_msg *msg, pv_param_t *param,
 /**
  *
  */
-int pv_get_mq_size(struct sip_msg *msg, pv_param_t *param,
-		pv_value_t *res)
+int pv_get_mq_size(struct sip_msg *msg, pv_param_t *param, pv_value_t *res)
 {
 	int mqs = -1;
 	str *in = pv_get_mq_name(msg, &param->pvn.u.isname.name.s);
 
-	if (in == NULL)
-	{
+	if(in == NULL) {
 		LM_ERR("failed to get mq name\n");
 		return -1;
 	}
 
 	mqs = _mq_get_csize(in);
 
-	if (mqs < 0)
-	{
+	if(mqs < 0) {
 		LM_ERR("mqueue not found: %.*s\n", in->len, in->s);
 		return -1;
 	}
@@ -559,7 +522,7 @@ int pv_get_mq_size(struct sip_msg *msg, pv_param_t *param,
 /**
  * Return head->csize for a given queue
  */
-int _mq_get_csize(str *name) 
+int _mq_get_csize(str *name)
 {
 	mq_head_t *mh = mq_head_get(name);
 	int mqueue_size = 0;
