@@ -4,6 +4,8 @@
  *
  * This file is part of Kamailio, a free SIP server.
  *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ *
  * Kamailio is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -92,6 +94,7 @@ static int pd_translate(sip_msg_t *msg, str *sdomain, int rmode, int fmode);
 
 static int w_pd_translate(struct sip_msg *msg, char *str1, char *str2);
 static int fixup_translate(void **param, int param_no);
+static int fixup_free_translate(void **param, int param_no);
 
 static int update_new_uri(struct sip_msg *msg, int plen, str *d, int mode);
 static int pdt_init_rpc(void);
@@ -100,12 +103,12 @@ static int pdt_init_rpc(void);
 static cmd_export_t cmds[] = {
 	{"prefix2domain", (cmd_function)w_prefix2domain,
 		0, 0, 0, REQUEST_ROUTE | FAILURE_ROUTE},
-	{"prefix2domain", (cmd_function)w_prefix2domain_1, 1, fixup_igp_null, 0,
-		REQUEST_ROUTE | FAILURE_ROUTE},
-	{"prefix2domain", (cmd_function)w_prefix2domain_2, 2, fixup_igp_igp, 0,
-		REQUEST_ROUTE | FAILURE_ROUTE},
-	{"pd_translate", (cmd_function)w_pd_translate, 2, fixup_translate, 0,
-		REQUEST_ROUTE | FAILURE_ROUTE | BRANCH_ROUTE},
+	{"prefix2domain", (cmd_function)w_prefix2domain_1, 1,
+		fixup_igp_null, fixup_free_igp_null, REQUEST_ROUTE | FAILURE_ROUTE},
+	{"prefix2domain", (cmd_function)w_prefix2domain_2, 2,
+		fixup_igp_igp, fixup_free_igp_igp, REQUEST_ROUTE | FAILURE_ROUTE},
+	{"pd_translate", (cmd_function)w_pd_translate, 2,
+		fixup_translate, fixup_free_translate, REQUEST_ROUTE | FAILURE_ROUTE | BRANCH_ROUTE},
 	{0, 0, 0, 0, 0, 0}
 };
 
@@ -117,13 +120,12 @@ static param_export_t params[] = {
 	{"domain_column", PARAM_STR, &domain_column},
 	{"prefix", PARAM_STR, &pdt_prefix},
 	{"char_list", PARAM_STR, &pdt_char_list},
-	{"fetch_rows", INT_PARAM, &pdt_fetch_rows},
-	{"check_domain", INT_PARAM, &pdt_check_domain},
+	{"fetch_rows", PARAM_INT, &pdt_fetch_rows},
+	{"check_domain", PARAM_INT, &pdt_check_domain},
 	{"mode", PARAM_INT, &_pdt_mode},
 	{0, 0, 0}
 };
 
-
 struct module_exports exports = {
 	"pdt",			 /* module name */
 	DEFAULT_DLFLAGS, /* dlopen flags */
@@ -429,6 +431,15 @@ static int fixup_translate(void **param, int param_no)
 	return 0;
 }
 
+static int fixup_free_translate(void **param, int param_no)
+{
+	if(param_no == 1)
+		return fixup_free_spve_null(param, 1);
+	if(param_no == 2)
+		return fixup_free_igp_null(param, 1);
+	return 0;
+}
+
 /**
  *
  */
