@@ -4,6 +4,8 @@
  *
  * This file is part of Kamailio, a free SIP server.
  *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ *
  * Kamailio is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -36,7 +38,9 @@
  *
  * =====================================================================================
  */
+#ifndef _GNU_SOURCE
 #define _GNU_SOURCE
+#endif
 #include <string.h>
 #include <unistd.h>
 #include <netinet/in.h>
@@ -366,6 +370,7 @@ int print_encoded_header(FILE *fd, char *msg, int msglen,
 {
 	char *hdr_start_ptr;
 	short int start_idx, i;
+	int j;
 
 	memcpy(&start_idx, payload, 2);
 	start_idx = ntohs(start_idx);
@@ -378,9 +383,9 @@ int print_encoded_header(FILE *fd, char *msg, int msglen,
 			hdr_start_ptr);
 	fprintf(fd, "%sHEADER:[%.*s]\n", prefix, i - 2, hdr_start_ptr);
 	fprintf(fd, "%sHEADER CODE=", prefix);
-	for(i = 0; i < len; i++)
-		fprintf(fd, "%s%d%s", i == 0 ? "[" : ":", payload[i],
-				i == len - 1 ? "]\n" : "");
+	for(j = 0; j < len; j++)
+		fprintf(fd, "%s%d%s", j == 0 ? "[" : ":", payload[j],
+				j == len - 1 ? "]\n" : "");
 	if(len == 4)
 		return 1;
 	switch(type) {
