@@ -14,15 +14,15 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License 
- * along with this program; if not, write to the Free Software 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- * 
+ *
  */
 
 #include "../../core/data_lump.h"
-#include "../../core/parser/msg_parser.h"	/* struct sip_msg */
+#include "../../core/parser/msg_parser.h" /* struct sip_msg */
 
 #ifndef _SIPT_SDP_MANGLE_
 #define _SIPT_SDP_MANGLE_
@@ -35,7 +35,9 @@ struct sdp_mangler
 };
 
 
-int replace_body_segment(struct sdp_mangler * mangler, int offset, int len, unsigned char * new_data, int new_len);
-int add_body_segment(struct sdp_mangler * mangler, int offset, unsigned char * new_data, int new_len);
+int replace_body_segment(struct sdp_mangler *mangler, int offset, int len,
+		unsigned char *new_data, int new_len);
+int add_body_segment(struct sdp_mangler *mangler, int offset,
+		unsigned char *new_data, int new_len);
 
 #endif
