@@ -5,6 +5,8 @@
  *
  * This file is part of Kamailio, a free SIP server.
  *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ *
  * Kamailio is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -70,12 +72,14 @@
 		(_d) += (_len);             \
 	} while(0)
 
+extern int tm_headers_mode;
 
 /* Build a local request based on a previous request; main
  * customers of this function are local ACK and local CANCEL
  */
 char *build_local(struct cell *Trans, unsigned int branch, unsigned int *len,
-		char *method, int method_len, str *to, struct cancel_reason *reason)
+		char *method, int method_len, str *to, sip_msg_t *imsg,
+		struct cancel_reason *reason)
 {
 	char *cancel_buf, *p, *via;
 	unsigned int via_len;
@@ -184,6 +188,28 @@ char *build_local(struct cell *Trans, unsigned int branch, unsigned int *len,
 			LM_BUG("unhandled reason cause %d\n", reason->cause);
 	}
 	*len += reason_len;
+	if(imsg != NULL && (tm_headers_mode & TM_CANCEL_HEADERS_COPY)) {
+		for(hdr = imsg->headers; hdr; hdr = hdr->next) {
+			switch(hdr->type) {
+				case HDR_CALLID_T:
+				case HDR_CSEQ_T:
+				case HDR_VIA_T:
+				case HDR_TO_T:
+				case HDR_FROM_T:
+				case HDR_ROUTE_T:
+				case HDR_MAXFORWARDS_T:
+				case HDR_REQUIRE_T:
+				case HDR_PROXYREQUIRE_T:
+				case HDR_CONTENTLENGTH_T:
+				case HDR_REASON_T:
+				case HDR_EOH_T:
+					/* skip these headers - they were added already */
+					break;
+				default:
+					*len += hdr->len;
+			}
+		}
+	}
 	*len += CRLF_LEN; /* end of msg. */
 
 	cancel_buf = shm_malloc(*len + 1);
@@ -255,6 +281,29 @@ char *build_local(struct cell *Trans, unsigned int branch, unsigned int *len,
 			}
 		}
 	}
+	if(imsg != NULL && (tm_headers_mode & TM_CANCEL_HEADERS_COPY)) {
+		for(hdr = imsg->headers; hdr; hdr = hdr->next) {
+			switch(hdr->type) {
+				case HDR_CALLID_T:
+				case HDR_CSEQ_T:
+				case HDR_VIA_T:
+				case HDR_TO_T:
+				case HDR_FROM_T:
+				case HDR_ROUTE_T:
+				case HDR_MAXFORWARDS_T:
+				case HDR_REQUIRE_T:
+				case HDR_PROXYREQUIRE_T:
+				case HDR_CONTENTLENGTH_T:
+				case HDR_REASON_T:
+				case HDR_EOH_T:
+					/* skip these headers - they were added already */
+					break;
+				default:
+					append_str(p, hdr->name.s, hdr->len);
+			}
+		}
+	}
+
 	append_str(p, CRLF, CRLF_LEN); /* msg. end */
 	*p = 0;
 
@@ -274,7 +323,7 @@ error:
  */
 char *build_local_reparse(tm_cell_t *Trans, unsigned int branch,
 		unsigned int *len, char *method, int method_len, str *to,
-		struct cancel_reason *reason)
+		sip_msg_t *imsg, struct cancel_reason *reason)
 {
 	char *invite_buf, *invite_buf_end;
 	char *cancel_buf;
@@ -288,6 +337,7 @@ char *build_local_reparse(tm_cell_t *Trans, unsigned int branch,
 	int hadded = 0;
 	sr_cfgenv_t *cenv = NULL;
 	hdr_flags_t hdr_flags = 0;
+	hdr_field_t *hf = NULL;
 
 	invite_buf = Trans->uac[branch].request.buffer;
 	invite_len = Trans->uac[branch].request.buffer_len;
@@ -345,6 +395,9 @@ char *build_local_reparse(tm_cell_t *Trans, unsigned int branch,
 	to_len = to ? to->len : 0;
 	cancel_buf_len = invite_len + to_len + reason_len;
 
+	if((imsg != NULL) && (tm_headers_mode & TM_CANCEL_HEADERS_COPY)) {
+		cancel_buf_len += imsg->len;
+	}
 	cancel_buf = shm_malloc(sizeof(char) * cancel_buf_len);
 	if(!cancel_buf) {
 		SHM_MEM_ERROR;
@@ -500,6 +553,29 @@ char *build_local_reparse(tm_cell_t *Trans, unsigned int branch,
 						}
 					}
 				}
+				if((imsg != NULL)
+						&& (tm_headers_mode & TM_CANCEL_HEADERS_COPY)) {
+					for(hf = imsg->headers; hf; hf = hf->next) {
+						switch(hf->type) {
+							case HDR_CALLID_T:
+							case HDR_CSEQ_T:
+							case HDR_VIA_T:
+							case HDR_TO_T:
+							case HDR_FROM_T:
+							case HDR_ROUTE_T:
+							case HDR_MAXFORWARDS_T:
+							case HDR_REQUIRE_T:
+							case HDR_PROXYREQUIRE_T:
+							case HDR_CONTENTLENGTH_T:
+							case HDR_REASON_T:
+							case HDR_EOH_T:
+								/* skip these headers - they were added already */
+								break;
+							default:
+								append_str(d, hf->name.s, hf->len);
+						}
+					}
+				}
 				/* final (end-of-headers) CRLF */
 				append_str(d, CRLF, CRLF_LEN);
 				*len = d - cancel_buf;
@@ -674,6 +750,26 @@ static inline int get_contact_uri(struct sip_msg *msg, str *uri)
 	return 0;
 }
 
+/**
+ * reverse rte list
+ */
+static inline rte_t *tm_reverse_rte_list(rte_t *head)
+{
+	rte_t *prev = NULL;
+	rte_t *current = NULL;
+	rte_t *next = NULL;
+
+	current = head;
+	while(current != NULL) {
+		next = current->next;
+		current->next = prev;
+		prev = current;
+		current = next;
+	}
+
+	return prev;
+}
+
 /**
  * Extract route set from the message (out of Record-Route, if reply, OR
  * Route, if request).
@@ -684,7 +780,7 @@ static inline int get_uac_rs(sip_msg_t *msg, int is_req, struct rte **rtset)
 {
 	struct hdr_field *ptr;
 	rr_t *p, *new_p;
-	struct rte *t, *head, *old_head;
+	struct rte *t, *head;
 
 	head = 0;
 	for(ptr = is_req ? msg->route : msg->record_route; ptr; ptr = ptr->next) {
@@ -734,14 +830,7 @@ static inline int get_uac_rs(sip_msg_t *msg, int is_req, struct rte **rtset)
 	if(is_req) {
 		/* harvesting the R/RR HF above inserts at head, which suites RRs (as
 		 * they must be reversed, anyway), but not Rs => reverse once more */
-		old_head = head;
-		head = 0;
-		while(old_head) {
-			t = old_head;
-			old_head = old_head->next;
-			t->next = head;
-			head = t;
-		}
+		head = tm_reverse_rte_list(head);
 	}
 
 	*rtset = head;
@@ -751,7 +840,6 @@ err:
 	return -1;
 }
 
-
 static inline unsigned short uri2port(const struct sip_uri *puri)
 {
 	if(puri->port.s) {
@@ -1739,7 +1827,8 @@ char *build_uac_cancel(str *headers, str *body, struct cell *cancelledT,
 	char branch_buf[MAX_BRANCH_PARAM_LEN];
 	str branch_str;
 	struct hostport hp;
-	str content_length, via;
+	str content_length;
+	str via = STR_NULL;
 
 	LM_DBG("sing FROM=<%.*s>, TO=<%.*s>, CSEQ_N=<%.*s>\n",
 			cancelledT->from_hdr.len, cancelledT->from_hdr.s,
@@ -1778,7 +1867,7 @@ char *build_uac_cancel(str *headers, str *body, struct cell *cancelledT,
 	/* Content Length  */
 	if(print_content_length(&content_length, body) < 0) {
 		LM_ERR("failed to print content-length\n");
-		return 0;
+		goto error01;
 	}
 	/* Content-Length */
 	*len += (body ? (CONTENT_LENGTH_LEN + content_length.len + CRLF_LEN) : 0);
