@@ -5,6 +5,8 @@
  *
  * This file is part of Kamailio, a free SIP server.
  *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ *
  * Kamailio is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -30,11 +32,9 @@
 #include "utime.h"
 
 
-time_t act_time;
+time_t ul_act_time = 0;
 
-
-void get_act_time(void)
+void ul_get_act_time(void)
 {
-
-	act_time = time(0);
+	ul_act_time = time(0);
 }
