@@ -7,6 +7,8 @@
  *
  * This file is part of Kamailio, a free SIP server.
  *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ *
  * Kamailio is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -99,7 +101,7 @@ static cmd_export_t cmds[] = {
 /* Exported parameters */
 static param_export_t params[] = {{"pres_db_url", PARAM_STR, &pres_db_url},
 		{"xcap_table", PARAM_STR, &xcap_table},
-		{"forward_active", INT_PARAM, &forward_active}, {0, 0, 0}};
+		{"forward_active", PARAM_INT, &forward_active}, {0, 0, 0}};
 
 #ifdef MI_REMOVED
 static mi_export_t mi_cmds[] = {
